﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Windows.DockManager;

namespace UnPinnedTabArea
{



    /// <summary>
    /// MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private Dictionary<string, ContentPane> dictionnaryPanes = new Dictionary<string, ContentPane>();

        public MainWindow()
        {
            InitializeComponent();
            AddContentPanes();
        }

        /// <summary>
        /// Dynamically add content panes to the split panes
        /// </summary>
        public void AddContentPanes()
        {
            UC1 userControl1 = new UC1();

            ContentPane pane1 = new ContentPane();
            pane1.SerializationId = "Pane1";
            pane1.Header = "My pane 1";
            pane1.Content = userControl1;

            dictionnaryPanes.Add(pane1.SerializationId, pane1);

            SplitDetail1.Panes.Add(pane1);

            UC2 userControl2 = new UC2();

            ContentPane pane2 = new ContentPane();
            pane2.SerializationId = "Pane2";
            pane2.Header = "My pane 2";
            pane2.Content = userControl2;

            SplitDetail2.Panes.Add(pane2);

            dictionnaryPanes.Add(pane2.SerializationId, pane2);

        }

        /// <summary>
        /// Reset layout dock manager
        /// (We cant use the LoadLayout() method because our panes are added dynamically by code depending on users actions)
        /// </summary>
        public void ResetContentPanesPositions()
        {
            foreach (ContentPane pane in dictionnaryPanes.Values)
            {
                if (pane.Parent != null && (pane.Parent is SplitPane || pane.Parent is UnpinnedTabArea))
                {

                    if (pane.Parent is SplitPane)
                    {
                        ((SplitPane)pane.Parent).Panes.Remove(pane);  //works fine => pane.parent = null after that
                    }

                    if (pane.Parent is UnpinnedTabArea) 
                    {
                        pane.ExecuteCommand(ContentPaneCommands.Close); //doesnt work => pane.Parent is still UnpinndTabArea after that

                        ///////////////////////////// Here are my unsuccessfull attempts ///////////////////////////////////////////
                        
                        //((pane.Parent as UnpinnedTabArea).ItemsSource.AsQueryable() as IQueryable<ContentPane>).ToList().Remove(pane);
                        //(pane.Parent as UnpinnedTabArea).Items.RemoveAt(0);
                        //(pane.Parent as UnpinnedTabArea).ItemsSource = null
                        
                        //pane.InvalidateVisual();
                        //pane.UpdateLayout();

                        //(pane.Parent as UnpinnedTabArea).InvalidateVisual();
                        //(pane.Parent as UnpinnedTabArea).UpdateLayout();

                        //xamDockManager1.InvalidateVisual();
                        //xamDockManager1.UpdateLayout();

                        ////////////////////////////////////////////////////////////////////////////////////////////////////////////
                    }

                    if (pane.SerializationId.Contains("Pane1"))
                    {
                        SplitDetail1.Panes.Clear();
                        SplitDetail1.Panes.Add(pane); //fails if pane belongs to an unpinnedtabarea
                    }

                    if (pane.SerializationId.Contains("Pane2"))
                    {
                        SplitDetail2.Panes.Clear();
                        SplitDetail2.Panes.Add(pane); //fails if pane belongs to an unpinnedtabarea
                    }
                }
            }
        }

        /// <summary>
        /// Reset position click
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnResetPositions_Click(object sender, RoutedEventArgs e)
        {
            ResetContentPanesPositions();
        }
    }
}
